@@ -607,3 +607,9 @@ bool MainWindow::selectPrevKeyset()
 {
   return selectKeysetForm->selectPrevKeyset();
 }
+
+
+bool MainWindow::selectFirstKeyset()
+{
+  return selectKeysetForm->selectFirstKeyset();
+}
